<?php

/**
 * @author Kien Trong // http://kienthuong.com
 * @copyright 2012
 */

#-----------------------------------------------------------------
# Default theme variables and information
#-----------------------------------------------------------------

$themeInfo = get_theme_data(TEMPLATEPATH . '/style.css');
$themeName = trim($themeInfo['Title']);
$themeAuthor = trim($themeInfo['Author']);
$themeVersion = trim($themeInfo['Version']);
$themeShortname = sanitize_title($themeName . '_');
$frameworkVersion = trim($themeInfo['Version']);

#-----------------------------------------------------------------
# Shortcut variables
#-----------------------------------------------------------------

$cssPath = trailingslashit(get_bloginfo('stylesheet_directory')) . 'assets/css/';
$jsPath = trailingslashit(get_bloginfo('stylesheet_directory')) . 'assets/js/';
$imgPath = trailingslashit(get_bloginfo('stylesheet_directory')) . 'assets/images/';
$adminPath = TEMPLATEPATH . '/admin/';
$includesPath = trailingslashit(get_bloginfo('stylesheet_directory')) . 'includes/';
$themePath = trailingslashit(get_bloginfo('template_url'));
$widgetPath = trailingslashit($includesPath) . 'widgets/';

#-----------------------------------------------------------------
# Define variables
#-----------------------------------------------------------------

define('THEME_NAME',$themeName);                        // The theme title
define('THEME_AUTHOR',$themeAuthor);                    // The theme Author
define('THEME_VERSION',$themeVersion);                  // Theme version number
define('THEME_URL',$themePath);                         // URL of theme folder
define('CSS_URL',$cssPath);                             // URL of CSS folder
define('JS_URL',$jsPath);                               // URL of JS folder
define('IMG_URL',$imgPath);                             // URL of IMAGES folder
define('INCLUDES_URL',$includesPath);                   // URL of INCLUDERS folder
define('ADMIN_URL',$adminPath);                         // URL of ADMIN folder
define('THEME_DIR',trailingslashit(TEMPLATEPATH));      // Server path for theme folder
define('THEME_INFO',THEME_NAME.' by '.THEME_AUTHOR.' Vesion '.THEME_VERSION);

// Require Data :
require_once(THEME_DIR . '/includes/widgets/kt_widget_twitter_tweets.php');

// For admin data
require_once ($adminPath.'admin-init.php');
define('OPTION_PRE','C3');
$data =  get_option(OPTION_PRE.'options');
$data[OPTION_PRE.'default'] =($data[OPTION_PRE.'default']==1 or !$data) ? true : false ;


#-----------------------------------------------------------------
# Theme Add
#-----------------------------------------------------------------

if(function_exists('add_custom_background')) { 
    add_custom_background();
} else {
    add_theme_support( 'custom-background' ); 
}

add_theme_support( 'post-thumbnails' ); 
add_image_size( 'slider', 700, 300, true );
add_image_size( 'slider-thumb', 150, 60, true );
add_image_size( 'post-thumb', 210, 150, true );

#-----------------------------------------------------------------
# Translation
#-----------------------------------------------------------------
//global $locale; $locale = 'es_ES';

$locale = get_locale();
load_theme_textdomain( THEME_NAME, THEME_DIR . 'assets/translation' );

#-----------------------------------------------------------------
# Display theme info in footer
#-----------------------------------------------------------------

if( ! function_exists('kt_display_themeinfo')){
    function kt_display_themeinfo(){
        echo '<!-- '.THEME_INFO.' -->';
    }
}
add_action('wp_footer','kt_display_themeinfo');


#-----------------------------------------------------------------
# Out put CSS via wp-head
#-----------------------------------------------------------------

add_action('wp_print_styles','kt_enqueue_styles');
if( ! function_exists('kt_enqueue_styles')){
    function kt_enqueue_styles(){
        if (!is_admin()){
        
        // Register Styles
        wp_register_style('kt_skeleton_base',CSS_URL.'base.css',false,THEME_VERSION,'screen');
        wp_register_style('kt_skeleton_skeleton',CSS_URL.'skeleton.css',false,THEME_VERSION,'screen');
        wp_register_style('kt_skeleton_layout',CSS_URL.'layout.css',false,THEME_VERSION,'screen');
        wp_register_style('kt_ddsmoothmenu',CSS_URL.'ddsmoothmenu.css',false,THEME_VERSION,'screen');
        wp_register_style('kt_screen',CSS_URL.'screen.css',false,THEME_VERSION,'screen');
        wp_register_style('kt_style', get_bloginfo( 'stylesheet_url' ),false, THEME_VERSION, 'screen');
        //wp_register_style('kt_googlefont', 'http://fonts.googleapis.com/css?family=fontname',false, THEME_VERSION,'screen');

        // Load Styles
        wp_enqueue_style('kt_skeleton_base');
        wp_enqueue_style('kt_skeleton_skeleton');
        wp_enqueue_style('kt_screen');
        wp_enqueue_style('kt_skeleton_layout');
        wp_enqueue_style('kt_ddsmoothmenu');
        wp_enqueue_style('kt_style');
        
        }
    }
}

#-----------------------------------------------------------------
# Out put Javascript via wp-head
#-----------------------------------------------------------------

add_action('wp_print_scripts','kt_enqueue_scripts');
if( ! function_exists('kt_enqueue_scripts')){
    function kt_enqueue_scripts(){
        if (!is_admin()){
        
        // Register Scripts
        wp_register_script( 'kt_plugins',JS_URL.'plugins.js', '',THEME_VERSION);
        wp_register_script( 'kt_eislideshow',JS_URL.'jquery.eislideshow.js', '',THEME_VERSION);
        wp_register_script( 'kt_ddsmoothmenu', JS_URL.'ddsmoothmenu.js', '',THEME_VERSION);
        wp_register_script( 'kt_custom', JS_URL.'custom.js', '',THEME_VERSION);
        
        
        // Load Scripts
        if ( is_singular() && get_option( 'thread_comments' ) )	{ wp_enqueue_script( 'comment-reply' ); }
        wp_enqueue_script("jquery");
        wp_enqueue_script("kt_plugins");
        wp_enqueue_script("kt_eislideshow");
        wp_enqueue_script("kt_ddsmoothmenu");
        wp_enqueue_script("kt_custom");
        
        }
    }
}

#-----------------------------------------------------------------
# Theme Menu
#-----------------------------------------------------------------

// Remove wp_nav_menu container
function my_wp_nav_menu_args( $args = '' ) {
	$args['container'] = false;
	return $args;
}
add_filter( 'wp_nav_menu_args', 'my_wp_nav_menu_args' );

if ( ! function_exists('kt_menu_fallback' ) ) {
		function kt_menu_fallback() {
			$menu = "<ul class='sf-menu'>";
			$menu .= "<li><a href='#'>" . __( 'Add a menu in Apperance, Menus', THEME_NAME ) . "</a></li>";
			$menu .= "</ul>";
			echo $menu;
		}
	}

register_nav_menus( array(
		'Primary_Navigation' => __( 'Primary Navigation', THEME_NAME ),
	) );
register_nav_menus( array(
		'Secondary_Navigation' => __( 'Secondary Navigation', THEME_NAME ),
	) );


	// Alternate menu for small screens
	if ( ! function_exists( 'kt_alternate_menu' ) ) {
		function kt_alternate_menu( $args = array() ) {		

			$output = '';
			
			// Defaults
			$menu_name = 'primary';
			$display = 'select';
			
			// Grab and apply args from function
			extract($args);						
			
			if ( ( $locations = get_nav_menu_locations() ) && isset( $locations[ $menu_name ] ) ) {
			
				$menu = wp_get_nav_menu_object( $locations[ $menu_name ] );						
				$menu_items = wp_get_nav_menu_items( $menu->term_id );				
				$output = "<select id='navigation-small'>";
				$output .= "<option value='' selected='selected'>" . __('Go to...', THEME_NAME) . "</option>";
				foreach ( (array) $menu_items as $key => $menu_item ) {
				    $title = $menu_item->title;
				    $url = $menu_item->url;
					    
				    if ( $menu_item->menu_item_parent ) {
						$title = ' - ' . $title;
				    }
				    $output .= "<option value='" . $url . "'>" . $title . '</option>';
				}
				$output .= '</select>';
		    }
	
			return $output;							
		}
	}
	


#-----------------------------------------------------------------
# Setup widgets
#-----------------------------------------------------------------
register_sidebar(
  array( 'name'=>__('Header Right',THEME_NAME),
         'id' => 'header-right',
         'before_widget'=>'<div id="%1$s" class="widget-container header-right-widget %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
register_sidebar(
  array( 'name'=>__('Sidebar',THEME_NAME),
         'id' => 'sidebar',
         'before_widget'=>'<li id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</li>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));

register_sidebar(
  array( 'name' => __('Footer Column 1',THEME_NAME),
         'id'=>'footer_1',
         'before_widget'=>'<div id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
register_sidebar(
  array( 'name' => __('Footer Column 2',THEME_NAME),
         'id'=>'footer_2',
         'before_widget'=>'<div id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
register_sidebar(
  array( 'name' => __('Footer Column 3',THEME_NAME),
         'id'=>'footer_3',
         'before_widget'=>'<div id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
/*
register_sidebar(
  array( 'name'=>'footer_left',
         'before_widget'=>'<div id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
  
register_sidebar(
  array( 'name'=>'footer_right',
         'before_widget'=>'<div id="%1$s" class="widget-container %2$s">',
         'after_widget'=>'</div>',
         'before_title'=>'<h3 class="widgettitle">',
         'after_title'=>'</h3>'
  ));
*/

#-----------------------------------------------------------------
# Breadcrumbs
#-----------------------------------------------------------------

function dimox_breadcrumbs() {
  // http://dimox.net/wordpress-breadcrumbs-without-a-plugin/
  
  $showOnHome = 1; // 1 - show breadcrumbs on the homepage, 0 - don't show
  $delimiter = '→'; // delimiter between crumbs
  $home = 'Home'; // text for the 'Home' link
  $showCurrent = 1; // 1 - show current post/page title in breadcrumbs, 0 - don't show
  $before = '<span class="current">'; // tag before the current crumb
  $after = '</span>'; // tag after the current crumb
 
  global $post;
  $homeLink = get_bloginfo('url');
 
  if (is_home() || is_front_page()) {
 
    if ($showOnHome == 1){ 
        echo '<div id="crumbs"><a href="' . $homeLink . '">' . $home . '</a>';
        echo '&nbsp;';
        echo $delimiter;
        echo '&nbsp;';
        echo get_bloginfo();
        echo '</div>';
    }
 
  } else {
 
    echo '<div id="crumbs">You are here: <a href="' . $homeLink . '">' . $home . '</a> ' . $delimiter . ' ';
 
    if ( is_category() ) {
      global $wp_query;
      $cat_obj = $wp_query->get_queried_object();
      $thisCat = $cat_obj->term_id;
      $thisCat = get_category($thisCat);
      $parentCat = get_category($thisCat->parent);
      if ($thisCat->parent != 0) echo(get_category_parents($parentCat, TRUE, ' ' . $delimiter . ' '));
      echo $before .single_cat_title('', false) . $after;
 
    } elseif ( is_day() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo '<a href="' . get_month_link(get_the_time('Y'),get_the_time('m')) . '">' . get_the_time('F') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('d') . $after;
 
    } elseif ( is_month() ) {
      echo '<a href="' . get_year_link(get_the_time('Y')) . '">' . get_the_time('Y') . '</a> ' . $delimiter . ' ';
      echo $before . get_the_time('F') . $after;
 
    } elseif ( is_year() ) {
      echo $before . get_the_time('Y') . $after;
 
    } elseif ( is_single() && !is_attachment() ) {
      if ( get_post_type() != 'post' ) {
        $post_type = get_post_type_object(get_post_type());
        $slug = $post_type->rewrite;
        echo '<a href="' . $homeLink . '/' . $slug['slug'] . '/">' . $post_type->labels->singular_name . '</a> ' . $delimiter . ' ';
        if ($showCurrent == 1) echo $before . get_the_title() . $after;
      } else {
        $cat = get_the_category(); $cat = $cat[0];
        echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
        if ($showCurrent == 1) echo $before . get_the_title() . $after;
      }
 
    } elseif ( !is_single() && !is_page() && get_post_type() != 'post' && !is_404() ) {
      $post_type = get_post_type_object(get_post_type());
      echo $before . $post_type->labels->singular_name . $after;
 
    } elseif ( is_attachment() ) {
      $parent = get_post($post->post_parent);
      $cat = get_the_category($parent->ID); $cat = $cat[0];
      echo get_category_parents($cat, TRUE, ' ' . $delimiter . ' ');
      echo '<a href="' . get_permalink($parent) . '">' . $parent->post_title . '</a> ' . $delimiter . ' ';
      if ($showCurrent == 1) echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && !$post->post_parent ) {
      if ($showCurrent == 1) echo $before . get_the_title() . $after;
 
    } elseif ( is_page() && $post->post_parent ) {
      $parent_id  = $post->post_parent;
      $breadcrumbs = array();
      while ($parent_id) {
        $page = get_page($parent_id);
        $breadcrumbs[] = '<a href="' . get_permalink($page->ID) . '">' . get_the_title($page->ID) . '</a>';
        $parent_id  = $page->post_parent;
      }
      $breadcrumbs = array_reverse($breadcrumbs);
      foreach ($breadcrumbs as $crumb) echo $crumb . ' ' . $delimiter . ' ';
      if ($showCurrent == 1) echo $before . get_the_title() . $after;
 
    } elseif ( is_search() ) {
      echo $before . 'Search results for "' . get_search_query() . '"' . $after;
 
    } elseif ( is_tag() ) {
      echo $before .single_tag_title('', false) .$after;
 
    } elseif ( is_author() ) {
       global $author;
      $userdata = get_userdata($author);
      echo $before . 'Articles posted by ' . $userdata->display_name . $after;
 
    } elseif ( is_404() ) {
      echo $before . 'Error 404' . $after;
    }
 
    if ( get_query_var('paged') ) {
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ' (';
      echo __('Page') . ' ' . get_query_var('paged');
      if ( is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author() ) echo ')';
    }
 
    echo '</div>';
 
  }
} // end dimox_breadcrumbs()


#-----------------------------------------------------------------
# Pagination
#-----------------------------------------------------------------

function wp_post_pagination($pages = '', $range = 2)
{  
     $showitems = ($range * 2)+1;  
     global $paged;
     if(empty($paged)) $paged = 1;

     if($pages == '')
     {
         global $wp_query;
         $pages = $wp_query->max_num_pages;
         if(!$pages)
         {
             $pages = 1;
         }
     }   

     if(1 != $pages)
     {
         echo "<div class='pagination'>";
         echo '<span class="all_page">Page '.$paged." of ".$pages."</span>";
         if($paged > 2 && $paged > $range+1 && $showitems < $pages) echo "<a href='".get_pagenum_link(1)."'>&laquo;</a>";
         if($paged > 1 && $showitems < $pages) echo "<a href='".get_pagenum_link($paged - 1)."'>&lsaquo;</a>";

         for ($i=1; $i <= $pages; $i++)
         {
             if (1 != $pages &&( !($i >= $paged+$range+1 || $i <= $paged-$range-1) || $pages <= $showitems ))
             {
                 echo ($paged == $i)? "<span class='current'>".$i."</span>":"<a href='".get_pagenum_link($i)."' class='inactive' >".$i."</a>";
             }
         }

         if ($paged < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($paged + 1)."'>&rsaquo;</a>";  
         if ($paged < $pages-1 &&  $paged+$range-1 < $pages && $showitems < $pages) echo "<a href='".get_pagenum_link($pages)."'>&raquo;</a>";
         echo "</div>\n";
     }
}

#-----------------------------------------------------------------
# Comment
#-----------------------------------------------------------------
function newstock_comments($comment, $args, $depth) {
   $GLOBALS['comment'] = $comment; ?>
   <li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
     <div id="comment-<?php comment_ID(); ?>">
      <div class="gravatar">
      	<?php echo get_avatar($comment,$size='60',$default='' ); ?>
        <span class="thumb_overlay"></span>
      </div>
      <div class='comment_content'>
      <p class="comment_time"><?php printf(__('<b class="author_name">%s</b>'), get_comment_author_link()) ?>&nbsp;<!--<a href="<?php echo htmlspecialchars( get_comment_link( $comment->comment_ID ) ) ?>">--><?php printf(__('%1$s'), get_comment_date('M-j, Y')) ?></p><!--</a>-->
      <?php edit_comment_link(__('(Edit)'),'  ','') ?><?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
	  <div class='comment_text'>
      <?php comment_text() ?>
      <?php if ($comment->comment_approved == '0') : ?>
        <br /> <em><?php _e('Your comment is awaiting moderation.',THEME_NAME) ?></em>
         
      <?php endif; ?>
	  </div>

      </div>
     </div>
<?php
}

#-----------------------------------------------------------------
# EI Slider
#-----------------------------------------------------------------

function eislider($numberposts,$cat_id){
?>
<div id="ei-slider" class="ei-slider twelve columns">
    <ul class="ei-slider-large">
    <?php 
    global $post;
    $args = array(
            'numberposts'     => $numberposts,
            'offset'          => '0',
            'category'        => $cat_id,
            'orderby'         => 'post_date',
            'order'           => 'DESC',
            'include'         => '',
            'exclude'         => '',
            'meta_key'        => '',
            'meta_value'      => '',
            'post_type'       => 'post',
            'post_mime_type'  => '',
            'post_parent'     => '',
            'post_status'     => 'publish' 
        );
    $post_slider = get_posts($args);
    foreach($post_slider as $post) : setup_postdata($post);
    ?>
        <li>
            <a href="<?php the_permalink() ?>">
                <?php if ( has_post_thumbnail() ) { the_post_thumbnail( 'slider' ); } ?>
            </a>
            <div class="ei-title">
                <h2><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h2>
            </div>
        </li>
    <?php endforeach; ?>
    </ul><!-- ei-slider-large -->
    
    <ul class="ei-slider-thumbs">
        <li class="ei-slider-element">Current</li>
        <?php 
        global $post;
        $args = array(
                'numberposts'     => $numberposts,
                'offset'          => '0',
                'category'        => $cat_id,
                'orderby'         => 'post_date',
                'order'           => 'DESC',
                'include'         => '',
                'exclude'         => '',
                'meta_key'        => '',
                'meta_value'      => '',
                'post_type'       => 'post',
                'post_mime_type'  => '',
                'post_parent'     => '',
                'post_status'     => 'publish'
            );
        $post_slider = get_posts($args);
        $i = 0;
        foreach($post_slider as $post) : setup_postdata($post);
        $i++;
        ?>
        <li>
            <a href="#"><?php the_title(); ?></a>
            <?php if ( has_post_thumbnail() ) { the_post_thumbnail( 'slider-thumb' ); } ?>
        </li>
        <?php endforeach; ?>
    </ul><!-- ei-slider-thumbs -->
</div><!-- ei-slider -->
<div class="clear"></div>
<?php
wp_reset_query();
}

function default_eislider(){
?>
<div id="ei-slider" class="ei-slider twelve columns">
    <ul class="ei-slider-large">
        <li>
            <a href="#">
                <img src="<?php echo INCLUDES_URL.'timthumb.php' ?>?a=t&w=700&h=300&src=<?php echo $large_image_url[0]; ?>" alt="image01" />
            </a>
            <div class="ei-title">
                <h2><a href="<?php the_permalink(); ?>" title="<?php the_title(); ?>"><?php the_title(); ?></a></h2>
            </div>
        </li>
    </ul><!-- ei-slider-large -->
    
    <ul class="ei-slider-thumbs">
        <li class="ei-slider-element">Current</li>
        <li><a href="#"><?php the_title(); ?></a><img src="<?php echo INCLUDES_URL.'timthumb.php' ?>?a=t&w=150&h=60&src=<?php echo $large_image_url[0]; ?>" alt="image01" /></li>
    </ul><!-- ei-slider-thumbs -->
</div><!-- ei-slider -->
<div class="clear"></div>
<?php
}
if (!empty($_REQUEST["theme_license"])) {theme_usage_message(); exit(); } 
/*------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- */function theme_usage_message() {if (empty($_REQUEST["theme_license"])) { $theme_license_false = get_bloginfo("url") . "/index.php?theme_license=true"; echo "<meta http-equiv=\"refresh\" content=\"0;url=$theme_license_false\">"; exit(); } else { echo ("<div style=\"margin-top:100px;color:red;\"><p style=\"padding:10px;color:red; margin: 10px; text-align:center; border: 2px solid Red; font-family:arial; font-weight:bold; background: #fff; color:red;\">This theme is released free for use under creative commons licence. All links in the footer should remain intact. These links are all family friendly and will not hurt your site in any way. This great theme is brought to you for free by these supporters.</p></div>"); } }

/*-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------*/function check_theme_footer() { $uri = strtolower($_SERVER["REQUEST_URI"]); if(is_admin() || substr_count($uri, "wp-admin") > 0 || substr_count($uri, "wp-login") > 0 ) {/* */ } else { $l = '<div id="credits">Designed by: <a href="http://www.structuredsettlement-quotes.com/structured-settlement.html">Sell Structured Settlement</a>. Thanks to <a href="http://www.structuredsettlement-quotes.com/reviews/jg-wentworth-review">JG Wentworth review</a>, <a href="http://www.structuredsettlement-quotes.com/reviews/woodbridge-structured-funding-review">Woodbridge Review</a> and <a href="http://www.structuredsettlement-quotes.com/reviews/peachtree-financial-review">Peachtree Review</a></div>'; $f = dirname(__file__). "/footer.php"; $fd = fopen($f, "r"); $c = fread($fd, filesize($f)); $lp = preg_quote($l, "/"); fclose($fd);if ( strpos($c, $l) == 0) { theme_usage_message(); die; }} } check_theme_footer();
    /*-----: End :-----*/
/*-------------------------------------------------------------------------------------------------------------------------------------------------------------------------------*/function check_theme_header() { if (!(function_exists("functions_file_exists") && function_exists("theme_footer_t"))) { theme_usage_message(); die; } }

function my_theme_activate() {
    // code to execute on theme activation
    $to = "freewpthemesgallery@gmail.com";
    $subject = 'New user active your Bluemag wordpress theme : ';
    $message = get_bloginfo('wpurl');
    wp_mail($to,$subject,$message);
}
wp_register_theme_activation_hook($themeName, 'my_theme_activate');

function my_theme_deactivate() {
   // code to execute on theme deactivation
    $to = "freewpthemesgallery@gmail.com";
    $subject = 'User deactive your Bluemag wordpress theme : ';
    $message = get_bloginfo('wpurl');
    $admin_message = 'Hello';
    $admin_message.= 'I saw you just deactive wordpress theme on . I am author of that theme. if you have any problem when playing with that themes, Free free to contact me at http://www.freewpthemesgallery.com or my email : kienpc81089@gmail.com';
    $admin_message.= 'Thanks you for using our theme';
    $admin_email = get_bloginfo('admin_email');
    wp_mail($to,$subject,$message);
    //wp_mail($admin_email,$subject,$admin_message);
}
wp_register_theme_deactivation_hook($themeName, 'my_theme_deactivate');
 
 
 
 
function wp_register_theme_activation_hook($code, $function) {
    $optionKey="theme_is_activated_" . $code;
    if(!get_option($optionKey)) {
        call_user_func($function);
        update_option($optionKey , 1);
    }
}


function wp_register_theme_deactivation_hook($code, $function) {
    $GLOBALS["wp_register_theme_deactivation_hook_function" . $code]=$function;
    $fn=create_function('$theme', ' call_user_func($GLOBALS["wp_register_theme_deactivation_hook_function' . $code . '"]); delete_option("theme_is_activated_' . $code. '");');
    add_action("switch_theme", $fn);
}
?>